@@ -10,7 +10,7 @@ import os,web2ldapcnf
 class Web2LDAPConfig:
   """
   Base class for a web2ldap host-/backend configuration section.
-  
+
   Leave untouched!!!
   """
   def __init__(self,**kwargs):
@@ -145,7 +145,7 @@ ldap_def = {
     modify_constant_attrs=[
       # Mostly OpenLDAP
       'entryCSN','entryDN','entryUUID',
-      # see RFC 
+      # see RFC
       'createTimestamp','modifyTimestamp','creatorsName','modifiersName',
       # MS AD
       'uSNChanged','uSNCreated','whenChanged','whenCreated',
@@ -227,6 +227,7 @@ ldap_def = {
       'groupOfNames':r'Group <strong>%(cn)s</strong>',
       'groupOfUniqueNames':r'Group <strong>%(cn)s</strong>',
       'posixGroup':r'Posix group <strong>%(cn)s</strong> (%(gidNumber)s)',
+      'sambaDomain':r'Samba domain <strong>%(sambaDomainName)s</strong> (%(sambaSID)s)',
     },
 
     # Default for number of results shown per page
@@ -244,6 +245,9 @@ ldap_def = {
       'posixAccount':os.path.join(web2ldapcnf.templates_dir,'read_posixAccount.html'),
       'eduPerson':os.path.join(web2ldapcnf.templates_dir,'read_eduPerson.html'),
       'pwdPolicy':os.path.join(web2ldapcnf.templates_dir,'read_pwdPolicy.html'),
+      'sambaDomain':os.path.join(web2ldapcnf.templates_dir,'read_sambaDomain.html'),
+      'sambaSamAccount':os.path.join(web2ldapcnf.templates_dir,'read_sambaSamAccount.html'),
+      'sambaGroupMapping':os.path.join(web2ldapcnf.templates_dir,'read_sambaGroupMapping.html'),
     },
 
     # Maximum count of attribute values displayed when displaying a single entry
@@ -276,6 +280,9 @@ ldap_def = {
       'msOrganization':os.path.join(web2ldapcnf.templates_dir,'inputform_msOrganization.html'),
       'eduPerson':os.path.join(web2ldapcnf.templates_dir,'inputform_eduPerson.html'),
       'pwdPolicy':os.path.join(web2ldapcnf.templates_dir,'inputform_pwdPolicy.html'),
+      'sambaDomain':os.path.join(web2ldapcnf.templates_dir,'inputform_sambaDomain.html'),
+      'sambaSamAccount':os.path.join(web2ldapcnf.templates_dir,'inputform_sambaSamAccount.html'),
+      'sambaGroupMapping':os.path.join(web2ldapcnf.templates_dir,'inputform_sambaGroupMapping.html'),
     },
 
     # HTML template file used for displaying operational attributes
@@ -377,6 +384,8 @@ ldap_def = {
     session_track_control=1,
     read_template={
       # 'object class':'pathname of HTML template file'
+      'germanBankArrangement':os.path.join(web2ldapcnf.templates_dir,'read_germanBankArrangement.html'),
+      'musician':os.path.join(web2ldapcnf.templates_dir,'read_musician.html'),
       'inetOrgPerson':os.path.join(web2ldapcnf.templates_dir,'read_inetOrgPerson.html'),
       'account':os.path.join(web2ldapcnf.templates_dir,'read_account.html'),
       'organizationalPerson':os.path.join(web2ldapcnf.templates_dir,'read_inetOrgPerson.html'),
@@ -384,23 +393,29 @@ ldap_def = {
       'organization':os.path.join(web2ldapcnf.templates_dir,'read_organization.html'),
       'msOrganization':os.path.join(web2ldapcnf.templates_dir,'read_msOrganization.html'),
       'posixAccount':os.path.join(web2ldapcnf.templates_dir,'read_posixAccount.html'),
-      'germanBankArrangement':os.path.join(web2ldapcnf.templates_dir,'read_germanBankArrangement.html'),
-      'musician':os.path.join(web2ldapcnf.templates_dir,'read_musician.html'),
+      'eduPerson':os.path.join(web2ldapcnf.templates_dir,'read_eduPerson.html'),
       'pwdPolicy':os.path.join(web2ldapcnf.templates_dir,'read_pwdPolicy.html'),
+      'sambaDomain':os.path.join(web2ldapcnf.templates_dir,'read_sambaDomain.html'),
+      'sambaSamAccount':os.path.join(web2ldapcnf.templates_dir,'read_sambaSamAccount.html'),
+      'sambaGroupMapping':os.path.join(web2ldapcnf.templates_dir,'read_sambaGroupMapping.html'),
     },
     # HTML template file used for displaying input forms for entries
     # of specific object class
     input_template={
       # 'object class':'pathname of HTML template file'
+      'germanBankArrangement':os.path.join(web2ldapcnf.templates_dir,'inputform_germanBankArrangement.html'),
+      'musician':os.path.join(web2ldapcnf.templates_dir,'inputform_musician.html'),
       'inetOrgPerson':os.path.join(web2ldapcnf.templates_dir,'inputform_inetOrgPerson.html'),
       'account':os.path.join(web2ldapcnf.templates_dir,'inputform_account.html'),
       'msPerson':os.path.join(web2ldapcnf.templates_dir,'inputform_msPerson.html'),
       'posixAccount':os.path.join(web2ldapcnf.templates_dir,'inputform_posixAccount.html'),
       'organization':os.path.join(web2ldapcnf.templates_dir,'inputform_organization.html'),
       'msOrganization':os.path.join(web2ldapcnf.templates_dir,'inputform_msOrganization.html'),
-      'germanBankArrangement':os.path.join(web2ldapcnf.templates_dir,'inputform_germanBankArrangement.html'),
-      'musician':os.path.join(web2ldapcnf.templates_dir,'inputform_musician.html'),
+      'eduPerson':os.path.join(web2ldapcnf.templates_dir,'inputform_eduPerson.html'),
       'pwdPolicy':os.path.join(web2ldapcnf.templates_dir,'inputform_pwdPolicy.html'),
+      'sambaDomain':os.path.join(web2ldapcnf.templates_dir,'inputform_sambaDomain.html'),
+      'sambaSamAccount':os.path.join(web2ldapcnf.templates_dir,'inputform_sambaSamAccount.html'),
+      'sambaGroupMapping':os.path.join(web2ldapcnf.templates_dir,'inputform_sambaGroupMapping.html'),
     },
     addform_entry_templates={
       u'stroeder.com Person':os.path.join(web2ldapcnf.templates_dir,'add_msperson.ldif'),
