@@ -11,7 +11,7 @@ This module is distributed under the terms of the
 GPL (GNU GENERAL PUBLIC LICENSE) Version 2
 (see http://www.gnu.org/copyleft/gpl.html)
 
-$Id: gui.py,v 1.271 2012/10/03 21:15:36 michael Exp $
+$Id: gui.py,v 1.276 2013/02/08 18:40:10 michael Exp $
 """
 
 import os,urllib,ldap, \
@@ -22,7 +22,9 @@ from ldapurl import LDAPUrl,LDAPUrlExtension,isLDAPUrl
 from ldap.filter import escape_filter_chars
 from pyweblib.forms import escapeHTML
 
-from ldaputil.base import ParentDN,ParentDNList,explode_dn
+from ldaputil.base import \
+  ParentDN,ParentDNList,explode_dn, \
+  AD_LDAP49_ERROR_CODES,AD_LDAP49_ERROR_PREFIX
 
 from msbase import GrabKeys
 
@@ -69,7 +71,7 @@ def ReadTemplate(form,ls,config_key,form_desc=u'',tmpl_filename=None):
   return tmpl_str # ReadTemplate()
 
 
-def LDAPError2ErrMsg(e,form,charset='utf-8',template=r'%s'):
+def LDAPError2ErrMsg(e,form,charset='utf-8',template='{error_msg}<br>{matched_dn}'):
   """
   Converts a LDAPError exception into HTML error message
 
@@ -84,18 +86,7 @@ def LDAPError2ErrMsg(e,form,charset='utf-8',template=r'%s'):
     (must contain only a single placeholder)
   """
 
-  AD_LDAP49_ERROR_CODES = {
-    0x525:u'user not found',
-    0x52e:u'invalid credentials',
-    0x530:u'not permitted to logon at this time',
-    0x531:u'not permitted to logon at this workstation',
-    0x532:u'password expired',
-    0x533:u'account disabled',
-    0x701:u'account expired',
-    0x773:u'user must reset password',
-    0x775:u'user account locked',
-  }
-  AD_LDAP49_ERROR_PREFIX = 'AcceptSecurityContext error, data '
+  matched_dn = None
 
   if isinstance(e,ldap.TIMEOUT) or not e.args:
 
@@ -114,7 +105,6 @@ def LDAPError2ErrMsg(e,form,charset='utf-8',template=r'%s'):
 
   else:
 
-    matched_dn = None
     try:
       ErrMsg = u':\n'.join((
         unicode(e.args[0]['desc'],charset),
@@ -133,9 +123,20 @@ def LDAPError2ErrMsg(e,form,charset='utf-8',template=r'%s'):
         matched_dn = unicode(e.args[0].get('matched',''),charset)
       except KeyError:
         matched_dn = None
+
   ErrMsg = ErrMsg.replace(u'\r','').replace(u'\t','')
   ErrMsg_html = form.utf2display(ErrMsg,lf_entity='<br>')
-  return template % ErrMsg_html
+
+  # Add matchedDN to error message HTML if needed
+  if matched_dn:
+    matched_dn_html = '<br>Matched DN: %s' % (form.utf2display(matched_dn.decode(charset)))
+  else:
+    matched_dn_html = ''
+
+  return template.format(
+    error_msg=ErrMsg_html,
+    matched_dn=matched_dn_html
+  )
 
 
 def DisplayDN(sid,form,ls,dn,commandbutton=0,active_ldapurl=0,bindas_button=False):
@@ -496,7 +497,7 @@ def SimpleMessage(
 
 # Return a pretty HTML-formatted string describing a schema element
 # referenced by name or OID
-def SchemaElementName(sid,form,dn,schema,se_nameoroid,se_class,name_template=r'<strong>%s</strong>'):
+def SchemaElementName(sid,form,dn,schema,se_nameoroid,se_class,name_template=r'%s'):
   result = [name_template % (se_nameoroid.encode())]
   if se_class:
     se = schema.get_obj(se_class,se_nameoroid,None)
