@@ -11,12 +11,12 @@ This module is distributed under the terms of the
 GPL (GNU GENERAL PUBLIC LICENSE) Version 2
 (see http://www.gnu.org/copyleft/gpl.html)
 
-$Id: syntaxes.py,v 1.272 2012/08/25 14:07:20 michael Exp $
+$Id: syntaxes.py,v 1.285 2013/02/16 16:38:07 michael Exp $
 """
 
 import re,imghdr,sndhdr,urllib,datetime,time,utctime,ldap,ldapurl,pyweblib.forms, \
        ldaputil.base,ldap.schema,xml.etree.ElementTree, \
-       w2lapp.viewer,w2lapp.form,w2lapp.gui,mspki.util,w2lapp.cnf
+       w2lapp.viewer,w2lapp.form,w2lapp.gui,mspki.util,w2lapp.cnf,ldaputil.schema
 
 from types import StringType,UnicodeType,IntType,LongType,FloatType,ClassType
 
@@ -24,6 +24,11 @@ from ldaputil.base import is_dn
 
 from ldap.dn import explode_dn
 
+try:
+  from netaddr import IPAddress,IPNetwork
+except ImportError:
+  from ipaddr import IPAddress,IPNetwork
+
 # Detect Python Imaging Library (PIL)
 try:
   from PIL import Image as PILImage
@@ -109,18 +114,18 @@ class LDAPSyntax:
   reObj = None
 
   def __init__(self,sid,form,ls,dn,schema,attrType,attrValue,entry=None):
-    assert entry is None or isinstance(entry,ldap.schema.models.Entry), \
-      TypeError('entry must be ldap.schema.models.Entry but is %s' % (entry.__class__.__name__))
     self.attrType = attrType
     assert type(attrValue)==StringType or attrValue is None, "Argument 'attrValue' must be StringType or None"
     self.attrValue = attrValue
     self._sid = sid
     self._form = form
     self._ls = ls
+    self._schema = schema
     assert type(dn)==UnicodeType, "Argument 'dn' must be UnicodeType"
     self._dn = dn
-    self._schema = schema
-    self._entry = entry or {}
+    assert entry is None or isinstance(entry,ldaputil.schema.Entry), \
+      TypeError('entry must be ldaputil.schema.Entry but is %s' % (entry.__class__.__name__))
+    self._entry = entry or ldaputil.schema.Entry(self._schema,None,{})
 
   def setAttrValue(self,attrValue):
     self.validate(attrValue)
@@ -622,6 +627,36 @@ class IntegerRange(Integer):
     )
 
 
+class IPHostAddress(IA5String):
+  oid = 'IPAddress-oid'
+  desc = 'string representation of IPv4 or IPv6 address or network'
+  # Class in module ipaddr which parses address/network values
+
+  def sanitizeInput(self,attrValue):
+    return attrValue.strip()
+
+  def _validate(self,attrValue):
+    try:
+      _ = IPAddress(attrValue)
+    except ValueError,e:
+      return False
+    else:
+      return True
+
+
+class IPNetworkAddress(IPHostAddress):
+  oid = 'IPAddress-oid'
+  desc = 'string representation of IPv4 or IPv6 address'
+
+  def _validate(self,attrValue):
+    try:
+      _ = IPNetwork(attrValue)
+    except ValueError,e:
+      return False
+    else:
+      return True
+
+
 class IPServicePortNumber(IntegerRange):
   oid = 'IPServicePortNumber-oid'
   desc = 'Port number for an UDP- or TCP-based service'
@@ -629,6 +664,23 @@ class IPServicePortNumber(IntegerRange):
   maxValue = 65535
 
 
+class MacAddress(IA5String):
+  oid = 'MacAddress-oid'
+  desc = 'MAC address in hex-colon notation'
+  minLen = 17
+  maxLen = 17
+  reObj=re.compile(r'^([0-9a-f]{2}\:){5}[0-9a-f]{2}$')
+  nosepReObj = re.compile(r'^[0-9a-f]{12}$')
+
+  def sanitizeInput(self,attrValue):
+    attrValue = attrValue.strip().lower().replace('.','').replace('.','').replace(':','')
+    result = ':'.join([
+      attrValue[2*i:2*i+2]
+      for i in range(6)
+    ])
+    return result
+
+
 class RFC822Address(IA5String):
   oid = 'RFC822Address-oid'
   desc = 'RFC 822 mail address'
@@ -904,6 +956,7 @@ class MultilineText(DirectoryString):
 
 
 class PreformattedMultilineText(MultilineText):
+  oid = 'PreformattedMultilineText-oid'
   lineSep = '\n'
   cols = 66
 
@@ -931,10 +984,9 @@ class PostalAddress(MultilineText):
 class PrintableString(DirectoryString):
   oid = '1.3.6.1.4.1.1466.115.121.1.44'
   desc = 'Printable String'
-  reObj= re.compile('^[a-zA-Z0-9"()+,.=/:? -]*$')
+  reObj= re.compile("^[a-zA-Z0-9'()+,.=/:? -]*$")
   charset = 'ascii'
 
-
 class NumericString(PrintableString):
   oid = '1.3.6.1.4.1.1466.115.121.1.36'
   desc = 'Numeric String'
@@ -966,7 +1018,7 @@ class FacsimileTelephoneNumber(TelephoneNumber):
 class TelexNumber(PrintableString):
   oid = '1.3.6.1.4.1.1466.115.121.1.52'
   desc = 'Telex Number'
-
+  reObj= re.compile("^[a-zA-Z0-9'()+,.=/:?$ -]*$")
 
 class TeletexTerminalIdentifier(PrintableString):
   oid = '1.3.6.1.4.1.1466.115.121.1.51'
@@ -1058,16 +1110,17 @@ class DaysSinceEpoch(Integer):
       return Integer.displayValue(self,valueindex,commandbutton)
 
 
-class SelectList(LDAPSyntax,DirectoryString):
+class SelectList(DirectoryString):
   """
   Base class for dictionary based select lists which
   should not be used directly
   """
+  oid = 'SelectList-oid'
   attr_value_dict = {} # Mapping attribute value to attribute description
 
   def _sortedSelectOptions(self):
     current_attr_values = set([self._ls.uc_decode(v)[0] for v in self._entry.get(self.attrType,[])])
-    attr_value_u = self.formValue()
+    attr_value_u = DirectoryString.formValue(self)
     current_attr_value_dict = {}
     current_attr_value_dict.update(self.attr_value_dict)
     if not current_attr_value_dict.has_key(u''):
@@ -1077,7 +1130,7 @@ class SelectList(LDAPSyntax,DirectoryString):
     tmplist = [
       (x[1], x)
       for x in current_attr_value_dict.items()
-      if x[0]==self.attrValue or not x[0] in current_attr_values
+      if x[0]==attr_value_u or not x[0] in current_attr_values
     ]
     tmplist.sort()
     return [ x for (k,x) in tmplist ]
@@ -1115,6 +1168,7 @@ class SelectList(LDAPSyntax,DirectoryString):
 
 
 class PropertiesSelectList(SelectList):
+  oid = 'PropertiesSelectList-oid'
   properties_pathname = None
   properties_charset = 'utf-8'
   properties_delimiter = u'='
@@ -1139,6 +1193,7 @@ class PropertiesSelectList(SelectList):
 
 
 class DynamicValueSelectList(SelectList,DirectoryString):
+  oid = 'DynamicValueSelectList-oid'
   ldap_url = None
   valuePrefix = ''
   valueSuffix = ''
@@ -1148,35 +1203,22 @@ class DynamicValueSelectList(SelectList,DirectoryString):
     self.minLen = len(self.valuePrefix)+len(self.valueSuffix)
     SelectList.__init__(self,sid,form,ls,dn,schema,attrType,attrValue,entry)
 
-  def formValue(self):
-    attrValue = self.attrValue or ''
-    try:
-      result = self._ls.uc_decode(
-        attrValue[len(self.valuePrefix):len(attrValue)-len(self.valueSuffix)]
-      )[0]
-    except UnicodeDecodeError:
-      result = u'!!!snipped because of UnicodeDecodeError!!!'
-    return result
-
   def formField(self):
     self._doSearch()
     return SelectList.formField(self)
 
-  def sanitize(self,attrValue):
-    return ''.join((
-      self.valuePrefix,
-      self._ls.uc_encode(attrValue)[0],
-      self.valueSuffix,
-    ))
-
   def _searchReferencedEntry(self,attrValue):
     search_dn = self._determineSearchDN(self._dn,self.lu_obj.dn)
     try:
-      ldap_result = self._ls.l.search_s(
+      ldap_result = self._ls.l.search_ext_s(
         self._ls.uc_encode(search_dn)[0],
         self.lu_obj.scope,
-        '(&%s(%s=%s))' % (self.lu_obj.filterstr or '(objectClass=*)',self.lu_obj.attrs[0],attrValue),
-        attrlist=self.lu_obj.attrs
+        '(&%s(%s=%s))' % (
+          self.lu_obj.filterstr or '(objectClass=*)',
+          self.lu_obj.attrs[0],attrValue
+        ),
+        attrlist=self.lu_obj.attrs,
+        sizelimit=2,
       )
     except (
       ldap.NO_SUCH_OBJECT,
@@ -1214,7 +1256,10 @@ class DynamicValueSelectList(SelectList,DirectoryString):
         except (KeyError,IndexError),e:
           display_text,link_html = '',''
         else:
-          display_text = self._form.utf2display(attr_value_desc+u':')
+          if self.lu_obj.attrs[0].lower()==self.lu_obj.attrs[1].lower():
+            display_text = ''
+          else:
+            display_text = self._form.utf2display(attr_value_desc+u':')
           if commandbutton:
             link_html = self._form.applAnchor(
               'read','&raquo;',self._sid,
@@ -1286,7 +1331,11 @@ class DynamicValueSelectList(SelectList,DirectoryString):
       assert len(self.lu_obj.attrs or [])==1,"attrlist in ldap_url must be of length 1 if scope is base"
       list_attr = self.lu_obj.attrs[0]
       attr_values_u = [
-        self._ls.uc_decode(attr_value)[0]
+        ''.join((
+          self.valuePrefix,
+          self._ls.uc_decode(attr_value)[0],
+          self.valueSuffix,
+        ))
         for attr_value in entry_r[list_attr]
       ]
       self.attr_value_dict=dict([ (u,u) for u in attr_values_u ])
@@ -1300,13 +1349,20 @@ class DynamicValueSelectList(SelectList,DirectoryString):
         if not dn_r is None:
           entry_r[None] = [dn_r]
           try:
-            self.attr_value_dict[self._ls.uc_decode(entry_r[option_value_map][0])[0]] = self._ls.uc_decode(entry_r.get(option_text_map,entry_r[option_value_map])[0])[0]
+            self.attr_value_dict[
+              ''.join((
+                self.valuePrefix,
+                self._ls.uc_decode(entry_r[option_value_map][0])[0],
+                self.valueSuffix,
+              ))
+            ] = self._ls.uc_decode(entry_r.get(option_text_map,entry_r[option_value_map])[0])[0]
           except KeyError:
             pass
     return # _doSearch()
 
 
 class DynamicDNSelectList(DynamicValueSelectList,DistinguishedName):
+  oid = 'DynamicDNSelectList-oid'
 
   def _readReferencedEntry(self,dn):
     try:
